@@ -51,12 +51,3 @@ ls -lh $AUTOPKGTEST_TMP/*.sha256
 echo "[i] Comparing per-packet hashes:"
 diff $AUTOPKGTEST_TMP/out1.sha256 $AUTOPKGTEST_TMP/out2.sha256
 check_result
-echo "[i] Comparing ffprobe results:"
-echo -n "    * video1.mp4: "
-ffprobe -hide_banner $AUTOPKGTEST_TMP/video1.mp4 2>&1 | grep -v Input > $AUTOPKGTEST_TMP/ffprobe.1
-sha256sum $AUTOPKGTEST_TMP/ffprobe.1
-echo -n "    * video2.mp4: "
-ffprobe -hide_banner $AUTOPKGTEST_TMP/video2.mp4 2>&1 | grep -v Input > $AUTOPKGTEST_TMP/ffprobe.2
-sha256sum $AUTOPKGTEST_TMP/ffprobe.2
-diff $AUTOPKGTEST_TMP/ffprobe.1 $AUTOPKGTEST_TMP/ffprobe.2
-check_result
